License FAQ - MultiMolecule
Author: MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

Skip to content

# License FAQ

This License FAQ explains the terms and conditions under which you may use the data, models, code, configuration, documentation, and weights provided by the DanLing Team (also known as DanLing) (‘we’, ‘us’, or ‘our’). It serves as an addendum to our License.

## 0. Summary of Key Points

This summary provides key points from our license, but you can find out more details about any of these topics by clicking the link following each key point and by reading the full license.

What constitutes the ‘source code’ in MultiMolecule?

We consider everything in our repositories to be source code, including data, models, code, configuration, and documentation.

What constitutes the ‘source code’ in MultiMolecule?

Can I publish research papers using MultiMolecule?

It depends.

You can publish research papers on fully open access journals and conferences or preprint servers following the terms of the License.

You must obtain a separate license from us to publish research papers on closed access journals and conferences.

Can I publish research papers using MultiMolecule?

Can I use MultiMolecule for commercial purposes?

Yes, you can use MultiMolecule for commercial purposes under the terms of the License.

Can I use MultiMolecule for commercial purposes?

Do people affiliated with certain organizations have specific license terms?

Yes, people affiliated with certain organizations have specific license terms.

Do people affiliated with certain organizations have specific license terms?

## 1. What constitutes the “source code” in MultiMolecule?

We consider everything in our repositories to be source code.

The training process of machine learning models is viewed similarly to the compilation process of traditional software. As such, the model, code, configuration, documentation, and data used for training are all part of the source code, while the trained model weights are part of the object code.

We also consider research papers and manuscripts a special form of documentation, which are also part of the source code.

## 2. Can I publish research papers using MultiMolecule?

Since research papers are considered a form of source code, publishers are legally required to open-source all materials on their server to comply with the License if they publish papers using MultiMolecule. This is generally impractical for most publishers.

As a special exemption under section 7 of the License, we grant permission to publish research papers using MultiMolecule in fully open access journals, conferences, or preprint servers, provided all published manuscripts are made available under the GNU Free Documentation License (GFDL), or a Creative Commons license, or an OSI-approved license that permits the sharing of manuscripts.

For publishing in closed access journals or conferences, you must obtain a separate license from us. This typically involves co-authorship, a fee to support the project, or both. Contact us at multimolecule@zyc.ai for more information.

While not mandatory, we recommend citing the MultiMolecule project in your research papers.

## 3. Can I use MultiMolecule for commercial purposes?

Yes, MultiMolecule can be used for commercial purposes under the License. However, you must open-source any modifications to the source code and make them available under the License.

If you prefer to use MultiMolecule for commercial purposes without open-sourcing your modifications, you must obtain a separate license from us. This typically involves a fee to support the project. Contact us at multimolecule@zyc.ai for further details.

## 4. Do people affiliated with certain organizations have specific license terms?

YES!

If you are affiliated with an organization that has a separate license agreement with us, you may be subject to different license terms. Please consult your organization’s legal department to determine if you are subject to a separate license agreement.

Members of the following organizations automatically receive a non-transferable, non-sublicensable, and non-distributable MIT License to use MultiMolecule:

- Microsoft Research AI for Science
- DP Technology

This special license is considered an additional term under section 7 of the License. It is not redistributable, and you are prohibited from creating any independent derivative works. Any modifications or derivative works based on this license are automatically considered derivative works of MultiMolecule and must comply with all the terms of the License. This ensures that third parties cannot bypass the license terms or create separate licenses from derivative works.

## 5. How can I use MultiMolecule if my organization forbids the use of code under the AGPL License?

Some organizations, such as Google, have policies that prohibit the use of code under the AGPL License.

If you are affiliated with an organization that forbids the use of AGPL-licensed code, you must obtain a separate license from us. Contact us at multimolecule@zyc.ai for more information.

## 6. Can I use MultiMolecule if I am a federal employee of the United States Government?

No.

Code written by federal employees of the United States Government is not protected by copyright under 17 U.S. Code § 105.

As a result, federal employees of the United States Government cannot comply with the terms of the License.

## 7. Do we make updates to this FAQ?

In Short

Yes, we will update this FAQ as necessary to stay compliant with relevant laws.

We may update this license FAQ from time to time. The updated version will be indicated by an updated ‘Last Revised Time’ at the bottom of this license FAQ. If we make any material changes, we will notify you by posting the new license FAQ on this page. We are unable to notify you directly as we do not collect any contact information from you. We encourage you to review this license FAQ frequently to stay informed of how you can use our data, models, code, configuration, documentation, and weights.

2024-06-25 15:24:27

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

Manage settings